@@ -28,6 +28,9 @@ CORDOVA_PLATFORM_VERSIONS = {
     "ios" : "ios@6.2.0",
 }
 
+PLATFORM_IOS = 'ios'
+PLATFORM_ANDROID = 'android'
+
 class CordovaBuildError(Exception):
     pass
 
@@ -59,6 +62,8 @@ class CordovaAppBuilder:
     unsigned_release_aab_output_path = 'platforms/android/app/build/outputs/bundle/release/app-release-unsigned.aab'
     signed_release_aab_output_path = 'platforms/android/app/build/outputs/bundle/release/app-release.aab'
 
+    debug_apk_output_path = 'platforms/android/app/build/outputs/apk/debug/app-debug.apk'
+
     default_plugins = ['cordova-plugin-device', 'cordova-plugin-network-information', 'cordova-plugin-file',
                        'cordova-plugin-dialogs', 'cordova-plugin-splashscreen', 'cordova-sqlite-storage',
                        'cordova-plugin-datepicker', 'cordova-plugin-statusbar', 'cordova-plugin-camera',
@@ -208,7 +213,7 @@ class CordovaAppBuilder:
 
         commands = []
 
-        if platform == 'iOS':
+        if platform == PLATFORM_IOS:
             for plugin in self.ios_plugins:
                 commands.append([self.cordova_bin, 'plugin', 'add', CORDOVA_PLUGIN_VERSIONS[plugin]])
 
@@ -250,6 +255,36 @@ class CordovaAppBuilder:
 
             if create_process_completed.returncode != 0:
                 raise CordovaBuildError(create_process_completed.stderr)
+
+            # add custom config.xml if any
+            custom_config_xml_path = self._custom_config_xml_path(platform=platform)
+
+            if os.path.isfile(custom_config_xml_path):
+                self.logger.info('Copying custom config xml')
+                shutil.copyfile(custom_config_xml_path, self.config_xml_path)
+                
+                with open(self.config_xml_path, 'rb') as config_file:
+                    config_xml_tree = etree.parse(config_file)
+                
+                
+                # make sure widget.id and <name> are set correctly
+                # <widget xmlns="http://www.w3.org/ns/widgets" xmlns:cdv="http://cordova.apache.org/ns/1.0" id="[package_name]" version="5.0.385">
+                # <name>[self.meta_app_definition.name]</name>
+                
+                root = xml_tree.getroot()
+                root.attrib['id'] = package_name
+                
+                for child in root:
+                    tag_name = etree.QName(child.tag).localname
+                    if tag_name == 'name':
+                        child.text = self.meta_app_definition.name
+                        break
+                
+                with open(self.config_xml_path, 'wb') as config_file:
+                    xml_tree.write(config_file, encoding='utf-8', xml_declaration=True, pretty_print=True)
+                
+                
+
                 
             self.install_default_plugins()
 
@@ -272,7 +307,7 @@ class CordovaAppBuilder:
             for tag_attributes in preferences:
                 self._add_to_config_xml('preference', tag_attributes=tag_attributes)
             
-
+    
     #####################################################################################################
     # add WWW
     # determine if the www folder already is the apps one: check for www/settings,json
@@ -376,13 +411,7 @@ class CordovaAppBuilder:
 
         self.load_cordova()
 
-        self._build_blank_cordova_app('Android', rebuild=rebuild)
-
-        # add custom config.xml if any
-        custom_config_xml_path = self._custom_config_xml_path(platform='android')
-
-        if os.path.isfile(custom_config_xml_path):
-            shutil.copyfile(custom_config_xml_path, self.config_xml_path)
+        self._build_blank_cordova_app(PLATFORM_ANDROID, rebuild=rebuild)
 
         # set app version
         self.set_config_xml_app_version(self.meta_app_definition.current_version, self.build_number)
@@ -409,7 +438,7 @@ class CordovaAppBuilder:
         image_creator.generate_images_from_svg('launcherBackground')
         image_creator.generate_images_from_svg('splashscreen', varying_ratios=True)
 
-        self.logger.info('initiating cordova build android')
+        self.logger.info('initiating cordova build android for release aab')
         build_android_command = [self.cordova_bin, 'build', 'android', '--release', '--',
                                  '--keystore={0}'.format(keystore_path),
                                  '--storePassword={0}'.format(keystore_password),
@@ -421,21 +450,32 @@ class CordovaAppBuilder:
         if build_android_process_completed.returncode != 0:
             raise CordovaBuildError(build_android_process_completed.stderr)
 
+        # build debug apk
+        self.logger.info('initiating cordova build android for debug apk')
+        build_android_apk_command = [self.cordova_bin, 'build', 'android', '--',
+                                 '--keystore={0}'.format(keystore_path),
+                                 '--storePassword={0}'.format(keystore_password),
+                                 '--alias=localcosmos', '--password={0}'.format(key_password)]
 
-        return self._aab_filepath
+        build_android_apk_process_completed = subprocess.run(build_android_apk_command, stdout=PIPE, stderr=PIPE,
+                                                         cwd=self._app_cordova_path)
+
+        if build_android_apk_process_completed.returncode != 0:
+            raise CordovaBuildError(build_android_apk_process_completed.stderr)
+
+
+        return self._aab_filepath, self._apk_filepath
 
 
     @property
     def _aab_filepath(self):
+        # uses the default .aab filename created by cordova
         return os.path.join(self._app_cordova_path, self.signed_release_aab_output_path)
 
     @property
-    def _aab_filename(self):
-        package_name = self.meta_app_definition.package_name
-        version = self.meta_app_definition.current_version
-        build_number = self.meta_app_definition.build_number
-        filename = '{0}-{1}-{2}.aab'.format(package_name, version, build_number)
-        return filename
+    def _apk_filepath(self):
+        # uses the default .apk filename created by cordova
+        return os.path.join(self._app_cordova_path, self.debug_apk_output_path)
 
 
     ##############################################################################################################
@@ -560,7 +600,7 @@ class CordovaAppBuilder:
         
         self.load_cordova()
 
-        self._build_blank_cordova_app('iOS', rebuild=rebuild)
+        self._build_blank_cordova_app(PLATFORM_IOS, rebuild=rebuild)
         
         # set app version
         self.set_config_xml_app_version(self.meta_app_definition.current_version, self.build_number)
@@ -582,7 +622,6 @@ class CordovaAppBuilder:
         # enable wkwebview
         # self.config_xml_enable_wkwebview()
 
-
         self.logger.info('Adding ios platform')
         add_ios_command = [self.cordova_bin, 'platform', 'add', CORDOVA_PLATFORM_VERSIONS['ios']]
 
